#!/bin/bash
# Author : Guth (guth@ploposor.com)
# URL : http://www.monkey.org/~dugsong/dsniff/beta/dsniff-2.4b1.tar.gz
# PATCH : https://launchpad.net/ubuntu/hardy/+source/dsniff/2.4b1+debian-17ubuntu1/+files/dsniff_2.4b1+debian-17ubuntu1.diff.gz


# program name/version
FilenameFromUrl="$(grep 'U[R]L' $0 | rev | cut -d '/' -f1 | rev)"
PatchFromUrl="$(grep 'PA[T]CH' $0 | rev | cut -d '/' -f1 | rev)"
softname="$(echo $FilenameFromUrl | cut -d '-' -f1)"
softversion="$(echo $FilenameFromUrl | cut -d '-' -f2 | cut -d '.' -f -2 )"
#softversion='1.1.4'
#softname='dsniff'
PatchFile="$(echo $PatchFromUrl |rev | cut -d '.' -f2- | rev )"

# architecture/package version
arch='i486'
cpu='i686'
packageversion='54.1'

# number of parallel tasks of make
ntasks='-j2'

# parameters needed for the build process
buildir=$(pwd)
package="$softname-$softversion-$arch-$packageversion"
srcpkg="$buildir/$FilenameFromUrl"

if ! [ -f "$FilenameFromUrl" ]; then
    echo "Downloading the program tarball...$(grep 'U[R]L' $0 | rev | cut -d ' ' -f1 | cut -d "	" -f 1 | rev)"
    wget "$(grep 'U[R]L' $0 | rev | cut -d ' ' -f1 | cut -d "	" -f 1 | rev)" ||exit 0
fi


if ! [ -f "$PatchFile" ]; then
    echo "Downloading the patch tarball...$(grep 'PA[T]CH' $0 | rev | cut -d ' ' -f1 | cut -d "	" -f 1 | rev)"
    wget --no-check-certificate "$(grep 'PA[T]CH' $0 | rev | cut -d ' ' -f1 | cut -d "	" -f 1 | rev)" ||exit 0
    gunzip "$PatchFromUrl"
fi


# prepare the build result directory
dest="$buildir/$package"
rm -rf $dest ||exit 0
rm -f $package.* ||exit 0
mkdir -p $dest/usr/{bin,man/man1} ||exit 0
mkdir -p $dest/install ||exit 0
mkdir -p $dest/usr/src/$softname-$softversion ||exit 0
mkdir -p $dest/usr/doc/$softname-$softversion ||exit 0

# make a slack-desc file
cat <<EOF > $dest/install/slack-desc
       |-----handy-ruler------------------------------------------------------|
dsniff: dsniff BinChunker for Unix / Linux
dsniff:
dsniff: collection of tools for network auditing and penetration testing.
dsniff: dsniff, filesnarf, mailsnarf, msgsnarf, urlsnarf, and webspy passively
dsniff: monitor a network for interesting data (passwords, e-mail, files, etc.).
dsniff: arpspoof, dnsspoof, and macof facilitate the interception of network
dsniff: traffic normally unavailable to an attacker (e.g, due to layer-2
dsniff: switching). sshmitm and webmitm implement active monkey-in-the-middle
dsniff: attacks against redirected SSH and HTTPS sessions by exploiting
dsniff: weak bindings in ad-hoc PKI.
dsniff: 
EOF

# extract sources
echo "extracting ..."
srcdir="$softname-2.4"
cd $buildir ||exit 0
rm -rf $srcdir ||exit 0
tar zxf $FilenameFromUrl ||exit 0
cd $srcdir ||exit 0

# set correct permissions
chown -R root.root .
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;

echo "configuring ..."

patch -p1 < "$buildir/$PatchFile"
for i in `cat debian/patches/00list`; do
    patch -p1 < debian/patches/$i;
done


export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
./configure \
   --prefix=/usr \
   --with-x \
   --sysconfdir=/etc \
   --localstatedir=/var \
   --mandir=/usr/man ||exit 0

#   --with-libnet=/opt/usr \

# compile package
make $ntasks ||exit 0

# install package to the target directory
make install_prefix=$dest install ||exit 0

# copy the doc files

cp -a \
 CHANGES LICENSE README TODO \
 $dest/usr/doc/$softname-$softversion ||exit 0

# strip executables
echo "stripping ..."
( cd $dest
   find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
   find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# gzip man pages and info files
echo "gzipping ..."
gzip -9 $dest/usr/man/*/*
chown -R root.root $dest/usr/man/*/*


# put the ZenWalk build and other needed files in the right directory
cp -a "$buildir/$0" $dest/usr/src/$softname-$softversion ||exit 0
cp -a "$buildir/$PatchFile" $dest/usr/src/$softname-$softversion ||exit 0
chown -R root.root $dest/usr/src/$softname-$softversion ||exit 0
find $dest/usr/doc -type f -exec chmod 644 {} \;

# change files ownerships for $dest/usr/sbin
chown -R root.root $dest/usr/bin ||exit 0

# make the package and move it to the build directory

#------------------( Create The *.dep File )
echo "creating .dep ..."
cd $dest
#requiredbuilder -z $dest > $buildir/$package.dep ||exit 0

#echo "b44,glib2,libnids,openssl,xcb,xorg-libs" > $buildir/$package.dep ||exit 0
## xorg required only for graphs
echo "b44,glib2,libnids,openssl" > $buildir/$package.dep ||exit 0

cd $dest
/sbin/makepkg -l y -c n $package.tgz ||exit 0
mv $package.tgz $buildir ||exit 0

# computes the md5sum signature for the package
echo "creating .md5 ..."
cd $buildir ||exit 0
md5sum $package.tgz > $package.md5 ||exit 0


if [ "$1" == "--cleanup" ]; then
  rm -rf $dest
  rm -rf $srcdir
fi

echo "$(grep 'U[R]L' $0 | rev | cut -d ' ' -f1 | cut -d "	" -f 1 | rev)" > $package.src
echo "$(grep 'PA[T]CH' $0 | rev | cut -d ' ' -f1 | cut -d "	" -f 1 | rev)" >> $package.src
echo "http://zen-repo.meticul.eu/zen_stuffs/guth/packages/$softname/$0" >> $package.src
